/* XQF - Quake server browser and launcher
 * Copyright (C) 1998 Roman Pozlevich <roma@botik.ru>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef __PSEARCH_H__
#define __PSEARCH_H__

#include "xqf.h"


#define PSEARCH_HISTORY_MAXITEMS	16

enum psearch_res { PSEARCH_CANCEL = 0, PSEARCH_OK = 1, PSEARCH_USELAST = 2 };

extern	int test_player (struct player *p);
extern	enum psearch_res psearch_dialog (void);
extern	void psearch_free_data (void);


#endif /* __PSEARCH_H__ */

